==> kimageannotator_0.6.1.orig.tar.gz: kImageAnnotator-0.6.1/translations/kImageAnnotator_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Anordnen</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Ganz nach vorn</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Nach vorn</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Nach hinten</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Ganz nach hinten</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Dieses auswählen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Allgemeine Einstellungen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Bild Einstellungen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Textfarbe</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Nummerierung ab</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Unschärfe Faktor</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Objekt-Schatten</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Objekt-Einstellungen</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Andere schließen</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alle schließen</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Alle linksseitig schließen</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Alle rechtsseitig schließen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Werkzeugauswahl</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Aktiviert</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">Drehen</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Vertikal</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Sichtbarkeit von Rahmen und Füllungen</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Rahmen und Füllung</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Rahmen und keine Füllung</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Kein Rahmen und keine Füllung</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Schriftgröße</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Bild-Effekte</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Kein Effekt</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Schlagschatten</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Graustufen</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Farbe invertieren</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Gesperrt</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Wenn aktiviert, wird erzwungen, dass die
Zeichenfläche das Hintergrundbild beinhaltet.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Hintergrundfarbe der Zeichenfläche</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Bild drehen</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° im Uhrzeigersinn</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° gegen den Uhrzeigersinn</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Beliebig</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Positive Werte rotieren im Uhrzeigersinn, negative Werte gegen den Uhrzeigersinn.
Das Drehen um nicht 90°-Multiplikatoren kann zu Qualitätsverlusten führen.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Drehen</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Umdrehen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Bild skalieren</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Seitenverhältnis beibehalten</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Prozentzahl</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Aufkleber</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Rechteckige Markierung</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Ellipsen Markierung</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Stift Markierung</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Doppelpfeil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Strich</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Verschwommenheit</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Nummer mit Zeiger</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Aufkleber</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Verpixelung</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Sprechblase</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Text mit Pfeil</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Nummer mit Pfeil</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplizieren</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Vergrößern (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Verkleinern (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Zoom zurücksetzen (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Anordnen</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Ganz nach vorn</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Nach vorn</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Nach hinten</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Ganz nach hinten</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Dieses auswählen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Bedienelemente</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Allgemeine Einstellungen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Bild Einstellungen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Textfarbe</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Nummerierung ab</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Unschärfe Faktor</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Objekt-Schatten</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Objekt-Einstellungen</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Deckkraft</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Andere schließen</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alle schließen</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Alle linksseitig schließen</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Alle rechtsseitig schließen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Werkzeugauswahl</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Aktiviert</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Zuschneiden</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Drehen</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Leinwand verändern</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Sichtbarkeit von Rahmen und Füllungen</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Rahmen und Füllung</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Rahmen und keine Füllung</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Kein Rahmen und keine Füllung</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Schriftgröße</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Bild-Effekte</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Kein Effekt</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Schlagschatten</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Graustufen</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Farbe invertieren</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Gesperrt</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Wenn aktiviert, wird erzwungen, dass die
Zeichenfläche das Hintergrundbild beinhaltet.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Hintergrundfarbe der Zeichenfläche</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Bild drehen</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° im Uhrzeigersinn</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° gegen den Uhrzeigersinn</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Beliebig</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Positive Werte rotieren im Uhrzeigersinn, negative Werte gegen den Uhrzeigersinn.
Das Drehen um nicht 90°-Multiplikatoren kann zu Qualitätsverlusten führen.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Drehen</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Umdrehen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Bild skalieren</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Seitenverhältnis beibehalten</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Prozentzahl</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Aufkleber</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Rechteckige Markierung</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Ellipsen Markierung</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Stift Markierung</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Doppelpfeil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Strich</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Verschwommenheit</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Nummer mit Zeiger</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Aufkleber</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Verpixelung</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Sprechblase</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Text mit Pfeil</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Nummer mit Pfeil</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplizieren</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Vergrößern (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Verkleinern (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Zoom zurücksetzen (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Zoom zurücksetzen</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>Bild einpassen</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation>Bild in Ansicht einpassen (%1)</translation>
    </message>
</context>
</TS>
